<?php

namespace Drupal\remote_media_transcription\Service;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\media\MediaInterface;

/**
 * Service for managing media transcriptions.
 */
class TranscriptionManager {

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Constructs a new TranscriptionManager.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->configFactory = $config_factory;
  }

  /**
   * Gets the transcription settings.
   *
   * @return array
   *   The settings array.
   */
  public function getSettings() {
    $config = $this->configFactory->get('remote_media_transcription.settings');
    return [
      'showButtonText' => $config->get('show_button_text'),
      'hideButtonText' => $config->get('hide_button_text'),
      'animationSpeed' => $config->get('animation_speed'),
      'defaultState' => $config->get('default_state'),
    ];
  }

  /**
   * Saves a transcription for a media entity.
   */
  public function saveTranscription(MediaInterface $media, $transcription, $format) {
    try {
      if ($media->hasField('field_transcription')) {
        $media->set('field_transcription', [
          'value' => $transcription,
          'format' => $format,
        ]);
        $media->save();
        return TRUE;
      }
    }
    catch (\Exception $e) {
      \Drupal::logger('remote_media_transcription')
        ->error('Error saving transcription: @message', ['@message' => $e->getMessage()]);
    }
    return FALSE;
  }
} 